==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/ComponentRouteSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ComponentRouteSpecFluentImpl<A extends io.fabric8.openshift.api.model.ComponentRouteSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ComponentRouteSpecFluent<A>{
  public ComponentRouteSpecFluentImpl() {
  }
  public ComponentRouteSpecFluentImpl(io.fabric8.openshift.api.model.ComponentRouteSpec instance) {
    this.withHostname(instance.getHostname()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withServingCertKeyPairSecret(instance.getServingCertKeyPairSecret()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String hostname;
  private java.lang.String name;
  private java.lang.String namespace;
  private io.fabric8.openshift.api.model.SecretNameReferenceBuilder servingCertKeyPairSecret;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getHostname() {
    return this.hostname;
  }
  public A withHostname(java.lang.String hostname) {
    this.hostname=hostname; return (A) this;
  }
  public java.lang.Boolean hasHostname() {
    return this.hostname != null;
  }
  
  /**
   * Method is deprecated. use withHostname instead.
   */
  @java.lang.Deprecated
  public A withNewHostname(java.lang.String arg0) {
    return (A)withHostname(new String(arg0));
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(java.lang.String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public java.lang.Boolean hasNamespace() {
    return this.namespace != null;
  }
  
  /**
   * Method is deprecated. use withNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewNamespace(java.lang.String arg0) {
    return (A)withNamespace(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildServingCertKeyPairSecret instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getServingCertKeyPairSecret() {
    return this.servingCertKeyPairSecret!=null?this.servingCertKeyPairSecret.build():null;
  }
  public io.fabric8.openshift.api.model.SecretNameReference buildServingCertKeyPairSecret() {
    return this.servingCertKeyPairSecret!=null?this.servingCertKeyPairSecret.build():null;
  }
  public A withServingCertKeyPairSecret(io.fabric8.openshift.api.model.SecretNameReference servingCertKeyPairSecret) {
    _visitables.get("servingCertKeyPairSecret").remove(this.servingCertKeyPairSecret);
    if (servingCertKeyPairSecret!=null){ this.servingCertKeyPairSecret= new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(servingCertKeyPairSecret); _visitables.get("servingCertKeyPairSecret").add(this.servingCertKeyPairSecret);} return (A) this;
  }
  public java.lang.Boolean hasServingCertKeyPairSecret() {
    return this.servingCertKeyPairSecret != null;
  }
  public A withNewServingCertKeyPairSecret(java.lang.String name) {
    return (A)withServingCertKeyPairSecret(new SecretNameReference(name));
  }
  public io.fabric8.openshift.api.model.ComponentRouteSpecFluent.ServingCertKeyPairSecretNested<A> withNewServingCertKeyPairSecret() {
    return new io.fabric8.openshift.api.model.ComponentRouteSpecFluentImpl.ServingCertKeyPairSecretNestedImpl();
  }
  public io.fabric8.openshift.api.model.ComponentRouteSpecFluent.ServingCertKeyPairSecretNested<A> withNewServingCertKeyPairSecretLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return new io.fabric8.openshift.api.model.ComponentRouteSpecFluentImpl.ServingCertKeyPairSecretNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ComponentRouteSpecFluent.ServingCertKeyPairSecretNested<A> editServingCertKeyPairSecret() {
    return withNewServingCertKeyPairSecretLike(getServingCertKeyPairSecret());
  }
  public io.fabric8.openshift.api.model.ComponentRouteSpecFluent.ServingCertKeyPairSecretNested<A> editOrNewServingCertKeyPairSecret() {
    return withNewServingCertKeyPairSecretLike(getServingCertKeyPairSecret() != null ? getServingCertKeyPairSecret(): new io.fabric8.openshift.api.model.SecretNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.ComponentRouteSpecFluent.ServingCertKeyPairSecretNested<A> editOrNewServingCertKeyPairSecretLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return withNewServingCertKeyPairSecretLike(getServingCertKeyPairSecret() != null ? getServingCertKeyPairSecret(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ComponentRouteSpecFluentImpl that = (ComponentRouteSpecFluentImpl) o;
    if (hostname != null ? !hostname.equals(that.hostname) :that.hostname != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
    if (servingCertKeyPairSecret != null ? !servingCertKeyPairSecret.equals(that.servingCertKeyPairSecret) :that.servingCertKeyPairSecret != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(hostname,  name,  namespace,  servingCertKeyPairSecret,  additionalProperties,  super.hashCode());
  }
  public class ServingCertKeyPairSecretNestedImpl<N> extends io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl<io.fabric8.openshift.api.model.ComponentRouteSpecFluent.ServingCertKeyPairSecretNested<N>> implements io.fabric8.openshift.api.model.ComponentRouteSpecFluent.ServingCertKeyPairSecretNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ServingCertKeyPairSecretNestedImpl(io.fabric8.openshift.api.model.SecretNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this, item);
    }
    ServingCertKeyPairSecretNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.SecretNameReferenceBuilder builder;
    public N and() {
      return (N) ComponentRouteSpecFluentImpl.this.withServingCertKeyPairSecret(builder.build());
    }
    public N endServingCertKeyPairSecret() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/ComponentRouteSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ComponentRouteSpecFluentImpl<A extends io.fabric8.openshift.api.model.ComponentRouteSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ComponentRouteSpecFluent<A>{
  public ComponentRouteSpecFluentImpl() {
  }
  public ComponentRouteSpecFluentImpl(io.fabric8.openshift.api.model.ComponentRouteSpec instance) {
    this.withHostname(instance.getHostname()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withServingCertKeyPairSecret(instance.getServingCertKeyPairSecret()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String hostname;
  private java.lang.String name;
  private java.lang.String namespace;
  private io.fabric8.openshift.api.model.SecretNameReferenceBuilder servingCertKeyPairSecret;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getHostname() {
    return this.hostname;
  }
  public A withHostname(java.lang.String hostname) {
    this.hostname=hostname; return (A) this;
  }
  public java.lang.Boolean hasHostname() {
    return this.hostname != null;
  }
  
  /**
   * Method is deprecated. use withHostname instead.
   */
  @java.lang.Deprecated
  public A withNewHostname(java.lang.String arg0) {
    return (A)withHostname(new String(arg0));
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(java.lang.String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public java.lang.Boolean hasNamespace() {
    return this.namespace != null;
  }
  
  /**
   * Method is deprecated. use withNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewNamespace(java.lang.String arg0) {
    return (A)withNamespace(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildServingCertKeyPairSecret instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.SecretNameReference getServingCertKeyPairSecret() {
    return this.servingCertKeyPairSecret!=null?this.servingCertKeyPairSecret.build():null;
  }
  public io.fabric8.openshift.api.model.SecretNameReference buildServingCertKeyPairSecret() {
    return this.servingCertKeyPairSecret!=null?this.servingCertKeyPairSecret.build():null;
  }
  public A withServingCertKeyPairSecret(io.fabric8.openshift.api.model.SecretNameReference servingCertKeyPairSecret) {
    _visitables.get("servingCertKeyPairSecret").remove(this.servingCertKeyPairSecret);
    if (servingCertKeyPairSecret!=null){ this.servingCertKeyPairSecret= new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(servingCertKeyPairSecret); _visitables.get("servingCertKeyPairSecret").add(this.servingCertKeyPairSecret);} return (A) this;
  }
  public java.lang.Boolean hasServingCertKeyPairSecret() {
    return this.servingCertKeyPairSecret != null;
  }
  public A withNewServingCertKeyPairSecret(java.lang.String name) {
    return (A)withServingCertKeyPairSecret(new SecretNameReference(name));
  }
  public io.fabric8.openshift.api.model.ComponentRouteSpecFluent.ServingCertKeyPairSecretNested<A> withNewServingCertKeyPairSecret() {
    return new io.fabric8.openshift.api.model.ComponentRouteSpecFluentImpl.ServingCertKeyPairSecretNestedImpl();
  }
  public io.fabric8.openshift.api.model.ComponentRouteSpecFluent.ServingCertKeyPairSecretNested<A> withNewServingCertKeyPairSecretLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return new io.fabric8.openshift.api.model.ComponentRouteSpecFluentImpl.ServingCertKeyPairSecretNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ComponentRouteSpecFluent.ServingCertKeyPairSecretNested<A> editServingCertKeyPairSecret() {
    return withNewServingCertKeyPairSecretLike(getServingCertKeyPairSecret());
  }
  public io.fabric8.openshift.api.model.ComponentRouteSpecFluent.ServingCertKeyPairSecretNested<A> editOrNewServingCertKeyPairSecret() {
    return withNewServingCertKeyPairSecretLike(getServingCertKeyPairSecret() != null ? getServingCertKeyPairSecret(): new io.fabric8.openshift.api.model.SecretNameReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.ComponentRouteSpecFluent.ServingCertKeyPairSecretNested<A> editOrNewServingCertKeyPairSecretLike(io.fabric8.openshift.api.model.SecretNameReference item) {
    return withNewServingCertKeyPairSecretLike(getServingCertKeyPairSecret() != null ? getServingCertKeyPairSecret(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ComponentRouteSpecFluentImpl that = (ComponentRouteSpecFluentImpl) o;
    if (hostname != null ? !hostname.equals(that.hostname) :that.hostname != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
    if (servingCertKeyPairSecret != null ? !servingCertKeyPairSecret.equals(that.servingCertKeyPairSecret) :that.servingCertKeyPairSecret != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(hostname,  name,  namespace,  servingCertKeyPairSecret,  additionalProperties,  super.hashCode());
  }
  public class ServingCertKeyPairSecretNestedImpl<N> extends io.fabric8.openshift.api.model.SecretNameReferenceFluentImpl<io.fabric8.openshift.api.model.ComponentRouteSpecFluent.ServingCertKeyPairSecretNested<N>> implements io.fabric8.openshift.api.model.ComponentRouteSpecFluent.ServingCertKeyPairSecretNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ServingCertKeyPairSecretNestedImpl(io.fabric8.openshift.api.model.SecretNameReference item) {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this, item);
    }
    ServingCertKeyPairSecretNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.SecretNameReferenceBuilder(this);
    }
    io.fabric8.openshift.api.model.SecretNameReferenceBuilder builder;
    public N and() {
      return (N) ComponentRouteSpecFluentImpl.this.withServingCertKeyPairSecret(builder.build());
    }
    public N endServingCertKeyPairSecret() {
      return and();
    }
    
  }
  
}
